@@ -1,4 +1,4 @@
-/* $Id: generate_defs_gtk.cc,v 1.11 2004/02/14 13:52:01 murrayc Exp $ */
+/* $Id: generate_defs_gtk.cc,v 1.22 2006/05/16 18:03:21 murrayc Exp $ */
 
 /* generate_defs_gtk.cc
  *
@@ -63,7 +63,8 @@ int main (int argc, char *argv[])
             << get_defs( GDK_TYPE_SCREEN )
             << get_defs( GDK_TYPE_VISUAL )
             << get_defs( GDK_TYPE_WINDOW )
-
+    
+            << get_defs( GTK_TYPE_ABOUT_DIALOG )
             << get_defs( GTK_TYPE_ACCEL_GROUP )
             << get_defs( GTK_TYPE_ACCEL_LABEL )
             << get_defs( GTK_TYPE_ACTION )
@@ -72,6 +73,7 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_ALIGNMENT)
             << get_defs( GTK_TYPE_ARROW )
             << get_defs( GTK_TYPE_ASPECT_FRAME )
+            << get_defs( GTK_TYPE_ASSISTANT )
             << get_defs( GTK_TYPE_BIN )
             << get_defs( GTK_TYPE_BOX )
             << get_defs( GTK_TYPE_BUTTON )
@@ -80,16 +82,24 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_CHECK_BUTTON )
             << get_defs( GTK_TYPE_CHECK_MENU_ITEM )
             << get_defs( GTK_TYPE_CLIST ) /* Deprecated */
+            << get_defs( GTK_TYPE_CELL_LAYOUT )
             << get_defs( GTK_TYPE_CELL_RENDERER )
+            << get_defs( GTK_TYPE_CELL_RENDERER_ACCEL )
+            << get_defs( GTK_TYPE_CELL_RENDERER_COMBO )
+	    << get_defs( GTK_TYPE_CELL_RENDERER_PROGRESS )	    
             << get_defs( GTK_TYPE_CELL_RENDERER_TEXT )
             << get_defs( GTK_TYPE_CELL_RENDERER_TOGGLE )
             << get_defs( GTK_TYPE_CELL_RENDERER_PIXBUF )
+            << get_defs( GTK_TYPE_CELL_RENDERER_PROGRESS )
+            << get_defs( GTK_TYPE_CELL_RENDERER_SPIN )	
+            << get_defs( GTK_TYPE_CLIPBOARD )       
             << get_defs( GTK_TYPE_COLOR_BUTTON )   
             << get_defs( GTK_TYPE_COLOR_SELECTION )
             << get_defs( GTK_TYPE_COMBO ) /* Deprecated */
             << get_defs( GTK_TYPE_COMBO_BOX ) 
             << get_defs( GTK_TYPE_CONTAINER )
             << get_defs( GTK_TYPE_CTREE ) /* Deprecated */
+            << get_defs( GTK_TYPE_CELL_VIEW )
             << get_defs( GTK_TYPE_CURVE )
             << get_defs( GTK_TYPE_DIALOG )
             << get_defs( GTK_TYPE_DRAWING_AREA )
@@ -98,6 +108,7 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_EVENT_BOX )
             << get_defs( GTK_TYPE_EXPANDER )
             << get_defs( GTK_TYPE_FILE_FILTER )
+            << get_defs( GTK_TYPE_FILE_CHOOSER_BUTTON ) 
             << get_defs( GTK_TYPE_FILE_CHOOSER_DIALOG )
             << get_defs( GTK_TYPE_FILE_CHOOSER_WIDGET )                        
             << get_defs( GTK_TYPE_FILE_SELECTION ) /* Deprecated */
@@ -107,19 +118,23 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_FONT_SELECTION_DIALOG )
             << get_defs( GTK_TYPE_FRAME )
             << get_defs( GTK_TYPE_HANDLE_BOX )
+            << get_defs( GTK_TYPE_ICON_THEME )
             << get_defs( GTK_TYPE_IMAGE )
             << get_defs( GTK_TYPE_INPUT_DIALOG )
             << get_defs( GTK_TYPE_INVISIBLE )
             << get_defs( GTK_TYPE_ITEM )
+            << get_defs( GTK_TYPE_ICON_VIEW )
             << get_defs( GTK_TYPE_LABEL )
             << get_defs( GTK_TYPE_LAYOUT )
+            << get_defs( GTK_TYPE_LINK_BUTTON )
             << get_defs( GTK_TYPE_LIST )
             << get_defs( GTK_TYPE_LIST_ITEM )
             << get_defs( GTK_TYPE_MENU )
             << get_defs( GTK_TYPE_MENU_BAR )
             << get_defs( GTK_TYPE_MENU_ITEM )
             << get_defs( GTK_TYPE_MENU_SHELL )
-            << get_defs( GTK_TYPE_MESSAGE_DIALOG )
+            << get_defs( GTK_TYPE_MENU_TOOL_BUTTON )            
+	    << get_defs( GTK_TYPE_MESSAGE_DIALOG )
             << get_defs( GTK_TYPE_MISC )
             << get_defs( GTK_TYPE_NOTEBOOK )
             << get_defs( GTK_TYPE_OBJECT )
@@ -130,6 +145,11 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_PLUG )
 #endif /* G_OS_WIN32 */
             << get_defs( GTK_TYPE_PREVIEW )
+	    << get_defs( GTK_TYPE_PRINT_OPERATION )
+	    /*<< get_defs( GTK_TYPE_PRINTER )*/
+	    /*<< get_defs( GTK_TYPE_PRINT_JOB )*/
+	    /*<< get_defs( GTK_TYPE_PAGE_SETUP_UNIX_DIALOG )*/
+	    /*<< get_defs( GTK_TYPE_PRINT_UNIX_DIALOG )*/
             << get_defs( GTK_TYPE_PROGRESS )
             << get_defs( GTK_TYPE_PROGRESS_BAR )
             << get_defs( GTK_TYPE_RADIO_BUTTON )
@@ -137,6 +157,11 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_RADIO_ACTION )            
             << get_defs( GTK_TYPE_RADIO_MENU_ITEM )
             << get_defs( GTK_TYPE_RANGE )
+            << get_defs( GTK_TYPE_RECENT_CHOOSER )
+            << get_defs( GTK_TYPE_RECENT_CHOOSER_MENU )
+            << get_defs( GTK_TYPE_RECENT_CHOOSER_WIDGET )
+            << get_defs( GTK_TYPE_RECENT_FILTER )
+            << get_defs( GTK_TYPE_RECENT_MANAGER )
             << get_defs( GTK_TYPE_RULER )
             << get_defs( GTK_TYPE_SCALE )
             << get_defs( GTK_TYPE_SCROLLBAR )
@@ -150,6 +175,7 @@ int main (int argc, char *argv[])
 #endif /* G_OS_WIN32 */
             << get_defs( GTK_TYPE_SPIN_BUTTON )
             << get_defs( GTK_TYPE_STATUSBAR )
+            << get_defs( GTK_TYPE_STATUS_ICON )
             << get_defs( GTK_TYPE_STYLE )
             << get_defs( GTK_TYPE_TABLE )
             << get_defs( GTK_TYPE_TEAROFF_MENU_ITEM )
